@@ -3,12 +3,13 @@ from tempfile import NamedTemporaryFile
 from typing import Literal, Optional, Sequence, Set, cast
 
 from invoke import Collection, Context, Result, UnexpectedExit, task
-from outcome.devkit.invoke import env
-from outcome.devkit.invoke.tasks import clean as clean_tasks
 from outcome.utils.env import is_ci
 from pydantic import BaseModel, Field
 from rich.console import Console
 
+from outcome.devkit.invoke import env
+from outcome.devkit.invoke.tasks import clean as clean_tasks
+
 
 class PyrightDiagnosticRangeBoundary(BaseModel):
     line: int
@@ -116,9 +117,9 @@ def isort(c: Context):
     """Run isort."""
     directories = env.r(check_targets)
     if is_ci():
-        c.run(f'poetry run isort -rc {directories} --check-only')
+        c.run(f'poetry run isort {directories} --check-only')
     else:
-        c.run(f'poetry run isort -rc {directories}')
+        c.run(f'poetry run isort {directories}')
 
 
 @task(clean)
